@@ -56,7 +56,7 @@ public:
 
 	virtual operator const char*() const;
 	virtual SWKey &operator =(const char * ikey) {SWKey &retval = SWKey::operator =(ikey); parse(); return retval; }
-	virtual SWKey &operator =(SWKey &ikey);
+	virtual SWKey &operator =(const SWKey &ikey);
 	virtual SWKey &operator =(POSITION);
 	virtual SWKey &operator -=(int decrement);
 	virtual SWKey &operator +=(int increment);
